Index: trunk/DataCheck/Processing/RunCallisto.sh
===================================================================
--- trunk/DataCheck/Processing/RunCallisto.sh	(revision 16989)
+++ trunk/DataCheck/Processing/RunCallisto.sh	(revision 16990)
@@ -39,10 +39,10 @@
 setstatus "start" 
 
-check1=`root -q -b fact/callisto6.C\("\"$seqfile\""\,"\"$outpath\""\) | tee $logfile | intgrep`
+check1=`root -q -b fact/analysis/callisto.C\("\"$seqfile\""\,"\"$outpath\""\) | tee $logfile | intgrep`
 
 case $check1 in
    0)   printprocesslog "INFO callisto was successful for sequence "$seqnum" (check1=$check1)"
         ;;
    *)   printprocesslog "ERROR callisto6.C failed for sequence "$seqnum" (check1=$check1)"
         check=$check1
         ;;
@@ -39,10 +39,10 @@
    0)   printprocesslog "INFO callisto was successful for sequence "$seqnum" (check1=$check1)"
         ;;
-   *)   printprocesslog "ERROR callisto6.C failed for sequence "$seqnum" (check1=$check1)"
+   *)   printprocesslog "ERROR callisto.C failed for sequence "$seqnum" (check1=$check1)"
         check=$check1
         ;;
